@@ -27,11 +27,6 @@ RScriptExtension::RScriptExtension(QObject* parent) : Cantor::ScriptExtension(pa
 
 }
 
-RScriptExtension::~RScriptExtension()
-{
-
-}
-
 QString RScriptExtension::runExternalScript(const QString& path)
 {
     return QString::fromLatin1("source(\"%1\")").arg(path);
@@ -71,12 +66,6 @@ RVariableManagementExtension::RVariableManagementExtension(QObject* parent) : Ca
 
 }
 
-
-RVariableManagementExtension::~RVariableManagementExtension()
-{
-
-}
-
 QString RVariableManagementExtension::addVariable(const QString& name, const QString& value)
 {
         return setValue(name, value);
