@@ -52,8 +52,8 @@ private:
     std::string unlocalizeExpression(QString expr);
 
 public:
-    QalculateExpression( QalculateSession* session);
-    ~QalculateExpression();
+    explicit QalculateExpression( QalculateSession* session, bool internal = false);
+    ~QalculateExpression() override;
 
     void evaluate() override;
     void interrupt() override;
